@@ -1,6 +1,6 @@
 package Hubot::Response;
 {
-  $Hubot::Response::VERSION = '0.0.8';
+  $Hubot::Response::VERSION = '0.0.9';
 }
 use Moose;
 use namespace::autoclean;
@@ -37,7 +37,7 @@ sub reply {
 
 sub random {
     my ( $self, @items ) = @_;
-    return $items[ srand( scalar(@items) ) ];
+    return $items[ rand( scalar(@items) ) ];
 }
 
 sub finish {
