@@ -1,6 +1,6 @@
 package Hubot::Scripts::shorten;
 {
-  $Hubot::Scripts::shorten::VERSION = '0.0.8';
+  $Hubot::Scripts::shorten::VERSION = '0.0.9';
 }
 use strict;
 use warnings;
@@ -18,11 +18,10 @@ sub load {
         sub {
             my $msg   = shift;
             my $bitly = $msg->match->[0];
-            if (
-                length $bitly > 50
+            if (   length $bitly > 50
                 && $ENV{HUBOT_BITLY_USERNAME}
-                && $ENV{HUBOT_BITLY_API_KEY}
-            ) {
+                && $ENV{HUBOT_BITLY_API_KEY} )
+            {
                 my $uri = URI->new("http://api.bitly.com/v3/shorten");
                 $uri->query_form_hash(
                     login   => $ENV{HUBOT_BITLY_USERNAME},
